@@ -1,5 +1,5 @@
-gene_atomization <-
-function(m){tempzz = unlist(lapply(m@Abstract, function(x){tempa = strsplit(x, ".  ",fixed=T);tempa1 = which( nchar(tempa[[1]]) == max(nchar(tempa[[1]])));
+if(getRversion() >= "2.15.0") utils::globalVariables(c("common_words_new", "HGNCdata"));
+gene_atomization <-function(m){tempzz = unlist(lapply(m@Abstract, function(x){tempa = strsplit(x, ".  ",fixed=T);tempa1 = which( nchar(tempa[[1]]) == max(nchar(tempa[[1]])));
 tempb = unlist(strsplit(tempa[[1]][tempa1], ".",fixed = T));
 tempc = unlist(strsplit(tempb, ",",fixed = T));
 tempd = unlist(  strsplit(tempc, ":",fixed = T));
